@@ -3,7 +3,7 @@ from viur.datastore.types import KEY_SPECIAL_PROPERTY, DATASTORE_BASE_TYPES, Sor
 from viur.datastore.query import Query
 from viur.datastore.utils import fixUnindexableProperties, normalizeKey, keyHelper, IsInTransaction, GetOrInsert,\
 	encodeKey, acquireTransactionSuccessMarker
-from viur.datastore.transport import Get, Put, Delete, RunInTransaction, Collision
+from viur.datastore.transport import Get, Put, Delete, RunInTransaction, Collision, AllocateIDs
 
 __all__ = ["KEY_SPECIAL_PROPERTY", "DATASTORE_BASE_TYPES", "SortOrder", "SkelListRef", "Entity", "QueryDefinition",
 		   "Key", "Query", "fixUnindexableProperties", "normalizeKey", "keyHelper", "Get", "Put", "Delete",
